@@ -1,6 +1,6 @@
 import os
 import xyz
-import pca
+import pca_creation
 import pymol
 import clustering
 import stat
@@ -128,7 +128,7 @@ class ConformationalAnalysis(object):
                 while userPCA_Components >= xyz_df.shape[0]:
                     raise InvalidPCAError("The # of components must be less than {}".format(xyz_df.shape[0]))
 
-                userPCA_model, user_num_components,original_df = pca.pca_model(userPCA_Components, xyz_df)
+                userPCA_model, user_num_components,original_df = pca_creation.pca_model(userPCA_Components, xyz_df)
 
                 print()
                 print("Would you like to test with a different number of PCs?")
